EXPORTS
	??0RAttribute@Xml@@QAE@XZ @ 1 NONAME ; public: __thiscall Xml::RAttribute::RAttribute(void)
	??0RDocumentParameters@Xml@@QAE@XZ @ 2 NONAME ; public: __thiscall Xml::RDocumentParameters::RDocumentParameters(void)
	??0RStringDictionaryCollection@Xml@@QAE@XZ @ 3 NONAME ; public: __thiscall Xml::RStringDictionaryCollection::RStringDictionaryCollection(void)
	??0RTagInfo@Xml@@QAE@XZ @ 4 NONAME ; public: __thiscall Xml::RTagInfo::RTagInfo(void)
	??1CDictionaryCodePage@Xml@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall Xml::CDictionaryCodePage::~CDictionaryCodePage(void)
	?AddPreloadedDictionaryL@CParser@Xml@@QAEXABVTDesC8@@@Z @ 6 NONAME ; public: void __thiscall Xml::CParser::AddPreloadedDictionaryL(class TDesC8 const &)
	?Attribute@RAttribute@Xml@@QBEABVRTagInfo@2@XZ @ 7 NONAME ; public: class Xml::RTagInfo const & __thiscall Xml::RAttribute::Attribute(void)const 
	?CharacterSetName@RDocumentParameters@Xml@@QBEABVRString@@XZ @ 8 NONAME ; public: class RString const & __thiscall Xml::RDocumentParameters::CharacterSetName(void)const 
	?Close@RAttribute@Xml@@QAEXXZ @ 9 NONAME ; public: void __thiscall Xml::RAttribute::Close(void)
	?Close@RDocumentParameters@Xml@@QAEXXZ @ 10 NONAME ; public: void __thiscall Xml::RDocumentParameters::Close(void)
	?Close@RStringDictionaryCollection@Xml@@QAEXXZ @ 11 NONAME ; public: void __thiscall Xml::RStringDictionaryCollection::Close(void)
	?Close@RTagInfo@Xml@@QAEXXZ @ 12 NONAME ; public: void __thiscall Xml::RTagInfo::Close(void)
	?CodePage@CDictionaryCodePage@Xml@@QBEEXZ @ 13 NONAME ; public: unsigned char __thiscall Xml::CDictionaryCodePage::CodePage(void)const 
	?ConstructIndexMappingL@CDictionaryCodePage@Xml@@QAEXPBHW4TStringType@12@@Z @ 14 NONAME ; public: void __thiscall Xml::CDictionaryCodePage::ConstructIndexMappingL(int const *,enum Xml::CDictionaryCodePage::TStringType)
	?ConvertCharacterSetIdentifierToStandardNameL@CCharSetConverter@Xml@@QAEXKAAPAVHBufC8@@@Z @ 15 NONAME ; public: void __thiscall Xml::CCharSetConverter::ConvertCharacterSetIdentifierToStandardNameL(unsigned long,class HBufC8 * &)
	?ConvertFromUnicodeL@CCharSetConverter@Xml@@QAEHABVTDesC16@@KAAPAVHBufC8@@@Z @ 16 NONAME ; public: int __thiscall Xml::CCharSetConverter::ConvertFromUnicodeL(class TDesC16 const &,unsigned long,class HBufC8 * &)
	?ConvertToUnicodeL@CCharSetConverter@Xml@@QAEHKABVTDesC8@@AAPAVHBufC16@@@Z @ 17 NONAME ; public: int __thiscall Xml::CCharSetConverter::ConvertToUnicodeL(unsigned long,class TDesC8 const &,class HBufC16 * &)
	?ConvertUcs4CharactersToEncodingL@CCharSetConverter@Xml@@QAEHPAKHKAAPAVHBufC8@@@Z @ 18 NONAME ; public: int __thiscall Xml::CCharSetConverter::ConvertUcs4CharactersToEncodingL(unsigned long *,int,unsigned long,class HBufC8 * &)
	?Copy@RAttribute@Xml@@QAE?AV12@XZ @ 19 NONAME ; public: class Xml::RAttribute  __thiscall Xml::RAttribute::Copy(void)
	?Copy@RTagInfo@Xml@@QAE?AV12@XZ @ 20 NONAME ; public: class Xml::RTagInfo  __thiscall Xml::RTagInfo::Copy(void)
	?CurrentDictionaryL@RStringDictionaryCollection@Xml@@QBEAAVMStringDictionary@2@XZ @ 21 NONAME ; public: class Xml::MStringDictionary & __thiscall Xml::RStringDictionaryCollection::CurrentDictionaryL(void)const 
	?DisableFeature@CParser@Xml@@QAEHH@Z @ 22 NONAME ; public: int __thiscall Xml::CParser::DisableFeature(int)
	?EnableFeature@CParser@Xml@@QAEHH@Z @ 23 NONAME ; public: int __thiscall Xml::CParser::EnableFeature(int)
	?IsFeatureEnabled@CParser@Xml@@QBEHH@Z @ 24 NONAME ; public: int __thiscall Xml::CParser::IsFeatureEnabled(int)const 
	?LocalName@RTagInfo@Xml@@QBEABVRString@@XZ @ 25 NONAME ; public: class RString const & __thiscall Xml::RTagInfo::LocalName(void)const 
	?NewL@CDictionaryCodePage@Xml@@SAPAV12@PBUTStringTable@@00E@Z @ 26 NONAME ; public: static class Xml::CDictionaryCodePage * __cdecl Xml::CDictionaryCodePage::NewL(struct TStringTable const *,struct TStringTable const *,struct TStringTable const *,unsigned char)
	?NewL@CParser@Xml@@SAPAV12@ABVTDesC8@@AAVMContentHandler@2@@Z @ 27 NONAME ; public: static class Xml::CParser * __cdecl Xml::CParser::NewL(class TDesC8 const &,class Xml::MContentHandler &)
	?NewLC@CParser@Xml@@SAPAV12@ABVTDesC8@@AAVMContentHandler@2@@Z @ 28 NONAME ; public: static class Xml::CParser * __cdecl Xml::CParser::NewLC(class TDesC8 const &,class Xml::MContentHandler &)
	?Open@RAttribute@Xml@@QAEXABVRString@@000W4TAttributeType@2@@Z @ 29 NONAME ; public: void __thiscall Xml::RAttribute::Open(class RString const &,class RString const &,class RString const &,class RString const &,enum Xml::TAttributeType)
	?Open@RAttribute@Xml@@QAEXABVRString@@00W4TAttributeType@2@@Z @ 30 NONAME ; public: void __thiscall Xml::RAttribute::Open(class RString const &,class RString const &,class RString const &,enum Xml::TAttributeType)
	?Open@RDocumentParameters@Xml@@QAEXABVRString@@@Z @ 31 NONAME ; public: void __thiscall Xml::RDocumentParameters::Open(class RString const &)
	?Open@RTagInfo@Xml@@QAEXABVRString@@00@Z @ 32 NONAME ; public: void __thiscall Xml::RTagInfo::Open(class RString const &,class RString const &,class RString const &)
	?OpenDictionaryL@RStringDictionaryCollection@Xml@@QAEXABVTDesC8@@@Z @ 33 NONAME ; public: void __thiscall Xml::RStringDictionaryCollection::OpenDictionaryL(class TDesC8 const &)
	?OpenL@RStringDictionaryCollection@Xml@@QAEXXZ @ 34 NONAME ; public: void __thiscall Xml::RStringDictionaryCollection::OpenL(void)
	?ParseEndL@CParser@Xml@@QAEXXZ @ 35 NONAME ; public: void __thiscall Xml::CParser::ParseEndL(void)
	?ParseL@CParser@Xml@@QAEXABVTDesC8@@@Z @ 36 NONAME ; public: void __thiscall Xml::CParser::ParseL(class TDesC8 const &)
	?ParseL@Xml@@YAXAAVCParser@1@AAVRFs@@ABVTDesC16@@@Z @ 37 NONAME ; void __cdecl Xml::ParseL(class Xml::CParser &,class RFs &,class TDesC16 const &)
	?ParseL@Xml@@YAXAAVCParser@1@ABVTDesC8@@@Z @ 38 NONAME ; void __cdecl Xml::ParseL(class Xml::CParser &,class TDesC8 const &)
	?Prefix@RTagInfo@Xml@@QBEABVRString@@XZ @ 39 NONAME ; public: class RString const & __thiscall Xml::RTagInfo::Prefix(void)const 
	?PrepareCharConvL@CCharSetConverter@Xml@@QAEXAAIABVTDesC8@@@Z @ 40 NONAME ; public: void __thiscall Xml::CCharSetConverter::PrepareCharConvL(unsigned int &,class TDesC8 const &)
	?PrepareCharConvL@CCharSetConverter@Xml@@QAEXAAIH@Z @ 41 NONAME ; public: void __thiscall Xml::CCharSetConverter::PrepareCharConvL(unsigned int &,int)
	?PrepareToConvertToOrFromL@CCharSetConverter@Xml@@QAEXK@Z @ 42 NONAME ; public: void __thiscall Xml::CCharSetConverter::PrepareToConvertToOrFromL(unsigned long)
	?SetProcessorChainL@CParser@Xml@@QAEXABV?$RArray@VTUid@@@@@Z @ 43 NONAME ; public: void __thiscall Xml::CParser::SetProcessorChainL(class RArray<class TUid> const &)
	?SetValue@RAttribute@Xml@@QAEXABVRString@@@Z @ 44 NONAME ; public: void __thiscall Xml::RAttribute::SetValue(class RString const &)
	?StringDictionaryCollection@CParser@Xml@@QAEAAVRStringDictionaryCollection@2@XZ @ 45 NONAME ; public: class Xml::RStringDictionaryCollection & __thiscall Xml::CParser::StringDictionaryCollection(void)
	?StringPool@CParser@Xml@@QAEAAVRStringPool@@XZ @ 46 NONAME ; public: class RStringPool & __thiscall Xml::CParser::StringPool(void)
	?StringPool@RStringDictionaryCollection@Xml@@QAEAAVRStringPool@@XZ @ 47 NONAME ; public: class RStringPool & __thiscall Xml::RStringDictionaryCollection::StringPool(void)
	?StringPoolIndexFromToken@CDictionaryCodePage@Xml@@QBEHHW4TStringType@12@@Z @ 48 NONAME ; public: int __thiscall Xml::CDictionaryCodePage::StringPoolIndexFromToken(int,enum Xml::CDictionaryCodePage::TStringType)const 
	?StringTable@CDictionaryCodePage@Xml@@QBEPBUTStringTable@@W4TStringType@12@@Z @ 49 NONAME ; public: struct TStringTable const * __thiscall Xml::CDictionaryCodePage::StringTable(enum Xml::CDictionaryCodePage::TStringType)const 
	?TokenFromStringPoolIndex@CDictionaryCodePage@Xml@@QBEHHW4TStringType@12@@Z @ 50 NONAME ; public: int __thiscall Xml::CDictionaryCodePage::TokenFromStringPoolIndex(int,enum Xml::CDictionaryCodePage::TStringType)const 
	?Type@RAttribute@Xml@@QBE?AW4TAttributeType@2@XZ @ 51 NONAME ; public: enum Xml::TAttributeType  __thiscall Xml::RAttribute::Type(void)const 
	?Uri@RTagInfo@Xml@@QBEABVRString@@XZ @ 52 NONAME ; public: class RString const & __thiscall Xml::RTagInfo::Uri(void)const 
	?Value@RAttribute@Xml@@QBEABVRString@@XZ @ 53 NONAME ; public: class RString const & __thiscall Xml::RAttribute::Value(void)const 
	?ParseBeginL@CParser@Xml@@QAEXABVTDesC8@@@Z @ 54 NONAME ; public: void __thiscall Xml::CParser::ParseBeginL(class TDesC8 const &)
	?ParseBeginL@CParser@Xml@@QAEXXZ @ 55 NONAME ; public: void __thiscall Xml::CParser::ParseBeginL(void)
	?ParseL@Xml@@YAXAAVCParser@1@AAVRFile@@@Z @ 56 NONAME ; void Xml::ParseL(class Xml::CParser &, class RFile &)
	?MimeType@CMatchData@Xml@@QBE?BVTPtrC8@@XZ @ 57 NONAME ; class TPtrC8 const Xml::CMatchData::MimeType(void) const
	?NewL@CMatchData@Xml@@SAPAV12@ABVTDesC8@@@Z @ 58 NONAME ; class Xml::CMatchData * Xml::CMatchData::NewL(class TDesC8 const &)
	?NewL@CMatchData@Xml@@SAPAV12@XZ @ 59 NONAME ; class Xml::CMatchData * Xml::CMatchData::NewL(void)
	?NewL@CParser@Xml@@SAPAV12@ABVCMatchData@2@AAVMContentHandler@2@@Z @ 60 NONAME ; class Xml::CParser * Xml::CParser::NewL(class Xml::CMatchData const &, class Xml::MContentHandler &)
	?NewLC@CMatchData@Xml@@SAPAV12@ABVTDesC8@@@Z @ 61 NONAME ; class Xml::CMatchData * Xml::CMatchData::NewLC(class TDesC8 const &)
	?NewLC@CMatchData@Xml@@SAPAV12@XZ @ 62 NONAME ; class Xml::CMatchData * Xml::CMatchData::NewLC(void)
	?NewLC@CParser@Xml@@SAPAV12@ABVCMatchData@2@AAVMContentHandler@2@@Z @ 63 NONAME ; class Xml::CParser * Xml::CParser::NewLC(class Xml::CMatchData const &, class Xml::MContentHandler &)
	?ParseBeginL@CParser@Xml@@QAEXABVCMatchData@2@@Z @ 64 NONAME ; void Xml::CParser::ParseBeginL(class Xml::CMatchData const &)
	?ResolveL@CMatchData@Xml@@QBE?AVTUid@@AAV?$RArray@PAVCImplementationInformation@@@@@Z @ 65 NONAME ; class TUid Xml::CMatchData::ResolveL(class RArray<class CImplementationInformation *> &) const
	?SetCaseSensitivity@CMatchData@Xml@@QAEXH@Z @ 66 NONAME ; void Xml::CMatchData::SetCaseSensitivity(int)
	?SetLeaveOnMany@CMatchData@Xml@@QAEXH@Z @ 67 NONAME ; void Xml::CMatchData::SetLeaveOnMany(int)
	?SetMimeTypeL@CMatchData@Xml@@QAEXABVTDesC8@@@Z @ 68 NONAME ; void Xml::CMatchData::SetMimeTypeL(class TDesC8 const &)
	?SetRomOnly@CMatchData@Xml@@QAEXH@Z @ 69 NONAME ; void Xml::CMatchData::SetRomOnly(int)
	?SetVariantL@CMatchData@Xml@@QAEXABVTDesC8@@@Z @ 70 NONAME ; void Xml::CMatchData::SetVariantL(class TDesC8 const &)
	?Variant@CMatchData@Xml@@QBE?BVTPtrC8@@XZ @ 71 NONAME ; class TPtrC8 const Xml::CMatchData::Variant(void) const
	?ConvertFromUnicodeL@CCharSetConverter@Xml@@QAEHABVTDesC16@@KAAVTPtr8@@@Z @ 72 NONAME ; int Xml::CCharSetConverter::ConvertFromUnicodeL(class TDesC16 const &, unsigned long, class TPtr8 &)
	?ConvertToUnicodeL@CCharSetConverter@Xml@@QAEHKABVTDesC8@@AAVTPtr16@@@Z @ 73 NONAME ; int Xml::CCharSetConverter::ConvertToUnicodeL(unsigned long, class TDesC8 const &, class TPtr16 &)

